boofun.analysis.query\_complexity
===================================

.. automodule:: boofun.analysis.query_complexity


   .. rubric:: Functions

   .. autosummary::

      ambainis_complexity
      approximate_degree
      average_deterministic_complexity
      average_everywhere_sensitivity
      block_sensitivity_lower_bound
      bounded_error_randomized_complexity
      certificate_lower_bound
      deterministic_query_complexity
      everywhere_sensitivity
      exact_quantum_complexity
      general_adversary_bound
      nondeterministic_complexity
      nondeterministic_degree
      one_sided_approximate_degree
      one_sided_randomized_complexity
      polynomial_method_bound
      quantum_query_complexity
      sensitivity_lower_bound
      spectral_adversary_bound
      strong_nondeterministic_degree
      threshold_degree
      weak_nondeterministic_degree
      zero_error_randomized_complexity

   .. rubric:: Classes

   .. autosummary::

      QueryComplexityProfile
